from . import command

def start_monitor(pin):
    """Get value in x-axis from Grove Joystick."""
    command(f"Starting HR monitor on{pin}", "hs", "HS-OK", bytes([pin]))

def get_rate(pin):
    """Get value in x-axis from Grove Joystick."""
    result = command(f"Starting HR monitor on{pin}", "hr", int, bytes([pin]))
    return result


from . import command

def set_colour_rgb(pin, count, led, red, green, blue):
    """Set the RGB colour of an RGB LED

    Parameters:
      pin (int): digital pin
      count (int): number of chained LEDs
      led (int): index of led (starting at 0)
      red (int): 0-255
      green (int): 0-255
      blue (int): 0-255
    """

    command(f"Setting RGB LED {led} on {pin} to RGB ({red}, {green}, {blue})",
            "lr", "lC-OK", bytes([pin, count, led, red, green, blue]))

def set_colour_hsv(pin, count, led, hue, sat, val):
    """Set the HSV of the RGB LED.

    Parameters:
      pin (int): digital pin
      count (int): number of chained LEDs
      led (int): index of led (starting at 0)
      hue (float): 0-1
      sat (float): 0-1
      val (float): 0-1
    """

    command(f"Setting RGB LED to HSV ({hue}, {sat}, {val})",
            "lh", "lH-OK", bytes([pin, count, led, int(hue*255), int(sat*255), int(val*255)]))


from . import command
import math

#Min and max x, y, values when joystick connected to A3 on Grove Shield
#Determined experimentally
minX = 206
maxX = 798
minY = 797
maxY = 954


def getX():
    """Get value in x-axis from Grove Joystick."""
    result = command("Getting joystick value in x-axis on port A3", "ar", int, bytes([3]))
    x_norm = (2/(maxX-minX)*(result - minX) - 1)
    if -1 <= x_norm <= 1:
        return x_norm
    elif x_norm < -1:
        return -1.0
    else:
        return 1.0 

def getY():
    """Get value in x-axis from Grove Joystick."""
    result = command("Getting joystick value in y-axis on port A3", "ar", int, bytes([4]))
    
    y_norm = (2/(maxY-minY)*(result - minY) - 1)
    if -1 <= y_norm <= 1:
        return y_norm
    elif y_norm < -1:
        return -1.0
    else:
        return 1.0

def getR_Theta():
    """Get acceleration in x-axis from Grove Beginner Accelerometer."""

    x = getX()
    y = getY()

    r = (x**2 + y**2)**0.5
    theta = math.atan2(y, x)

    return (r, theta)